from mitama.http import Response, get_session


async def home(request):
    return Response()
